==> gwt-mt-widgets-0.55.5.jar: de/knightsoftnet/mtwidgets/client/ui/widget/helper/CurrencyDoubleRenderer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package de.knightsoftnet.mtwidgets.client.ui.widget.helper;

import com.google.gwt.i18n.client.NumberFormat;
import com.google.gwt.text.shared.AbstractRenderer;
import com.google.gwt.text.shared.Renderer;

import org.apache.commons.lang3.StringUtils;

/**
 * render double value to currency.
 *
 * @author Manfred Tremmel
 */
public class CurrencyDoubleRenderer extends AbstractRenderer<Double> {

  private static volatile CurrencyDoubleRenderer instanceRenderer = null;

  /**
   * returns the instance.
   *
   * @return CurrencyDoubleRenderer
   */
  public static final Renderer<Double> instance() { // NOPMD it's thread save!
    if (CurrencyDoubleRenderer.instanceRenderer == null) {
      synchronized (CurrencyDoubleRenderer.class) {
        if (CurrencyDoubleRenderer.instanceRenderer == null) {
          CurrencyDoubleRenderer.instanceRenderer = new CurrencyDoubleRenderer();
        }
      }
    }
    return CurrencyDoubleRenderer.instanceRenderer;
  }

  @Override
  public String render(final Double pobject) {
    if (pobject == null) {
      return StringUtils.EMPTY;
    }
    return NumberFormat.getCurrencyFormat().format(pobject);
  }
}

==> gwt-mt-widgets-2.0.17.jar: de/knightsoftnet/mtwidgets/client/ui/widget/helper/CurrencyDoubleRenderer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package de.knightsoftnet.mtwidgets.client.ui.widget.helper;

import com.google.gwt.i18n.client.NumberFormat;
import com.google.gwt.text.shared.AbstractRenderer;
import com.google.gwt.text.shared.Renderer;

import org.apache.commons.lang3.StringUtils;

/**
 * render double value to currency.
 *
 * @author Manfred Tremmel
 */
public class CurrencyDoubleRenderer extends AbstractRenderer<Double> {

  private static volatile CurrencyDoubleRenderer instanceRenderer = null;

  /**
   * returns the instance.
   *
   * @return CurrencyDoubleRenderer
   */
  public static final Renderer<Double> instance() { // NOPMD it's thread save!
    if (instanceRenderer == null) {
      synchronized (CurrencyDoubleRenderer.class) {
        if (instanceRenderer == null) {
          instanceRenderer = new CurrencyDoubleRenderer();
        }
      }
    }
    return instanceRenderer;
  }

  @Override
  public String render(final Double pobject) {
    if (pobject == null) {
      return StringUtils.EMPTY;
    }
    return NumberFormat.getCurrencyFormat().format(pobject);
  }
}
